@@ -4,13 +4,9 @@
 #define NOTE_TRUNCATE 0
 #endif
 
-#if defined(_LINUX_PORT) && defined(__GLIBC__)
-#include <sys/types.h>
-size_t strlcpy(char *dst, const char *src, size_t dsize);
-#endif
-
 #if defined(_LINUX_PORT)
 #define INOTIFY_MAX_USER_WATCHES 2
+size_t strlcpy(char *dst, const char *src, size_t dsize);
 int fs_sysctl(const int name);
 #endif
 
