@@ -1,18 +1,4 @@
-#!/bin/sh
-#
-# Copyright (c) 2012 Eric Radman <ericshane@eradman.com>
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+#!/bin/sh -u
 
 trap '' ERR 2> /dev/null || exec bash $0 "$@"
 
@@ -26,7 +12,7 @@ function assert {
 
 	echo "*************************************"
 	echo "System test directory contents:"
-	head -n 50 $(find $tmp -type f)
+	: | head -n 50 $(find $tmp -type f  ! -perm -111)
 	echo "*************************************"
 	exit 1
 }
@@ -41,6 +27,7 @@ function setup {
 tmp=$(cd $(mktemp -d ${TMPDIR:-/tmp}/entr-system-test-XXXXXX); pwd -P)
 tsession=$(basename $tmp)
 
+let tests=0
 clear_tty='test -t 0 && stty echo icanon'
 clear_tmux='tmux kill-session -t $tsession 2>/dev/null || true'
 clear_tmp='rm -rf $tmp'
@@ -65,27 +52,34 @@ if [ $(uname) == 'Linux' ]; then
 	}
 fi
 
+# local binary, non-interactive by default
+alias entr='./entr -n'
+alias entr_tty='./entr'
+
+# alias expansion is not enabled by default in non-interactive Bourne Again Shell (bash) sessions
+command -v shopt > /dev/null && shopt -s expand_aliases
+
 # fast tests
 
 try "no arguments"
-	./entr 2> /dev/null || code=$?
+	entr 2> /dev/null || code=$?
 	assert $code 1
 
 try "no input"
-	./entr echo "vroom" 2> /dev/null || code=$?
+	entr echo "vroom" 2> /dev/null || code=$?
 	assert $code 1
 
 try "reload and clear options with no utility to run"
-	./entr -r -c 2> /dev/null || code=$?
+	entr -r -c 2> /dev/null || code=$?
 	assert $code 1
 
 try "empty input"
-	echo "" | ./entr echo 2> /dev/null || code=$?
+	echo "" | entr echo 2> /dev/null || code=$?
 	assert $code 1
 
 try "no regular files provided as input"
 	mkdir $tmp/dir1
-	ls $tmp | ./entr echo 2> /dev/null || code=$?
+	ls $tmp | entr echo 2> /dev/null || code=$?
 	rmdir $tmp/dir1
 	assert $code 1
 
@@ -94,16 +88,15 @@ try "no regular files provided as input"
 try "install default status script"
 	setup
 	export ENTR_STATUS_SCRIPT="$tmp/status.awk"
-	ls $tmp/* | ./entr -zx true >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zx true >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	wait $bgpid
-	sed -i -e "s,'.*.awk',$1 /.../status.awk," $tmp/exec.out
 	assert "$(cat $tmp/exec.err)" ""
-	assert "$(cat $tmp/exec.out)" "$(printf 'entr: created  /.../status.awk\ntrue returned exit code 0\n')"
+	assert "$(cat $tmp/exec.out)" "$(printf "entr: created '$tmp/status.awk'\ntrue returned exit code 0\n")"
 
 try "status script not compatible with restart option"
 	setup
-	ls $tmp/* | ./entr -zrx true >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zrx true >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	wait $bgpid; assert "$?" "1"
 
@@ -113,7 +106,7 @@ try "block unsafe status script"
 	cat > $ENTR_STATUS_SCRIPT <<-EOF
 	{ system("date") }
 	EOF
-	ls $tmp/* | ./entr -zx true >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zx true >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	sed -i -e "s,.*awk: .*,awk: system is unsafe ... status.awk," $tmp/exec.err
 	assert "$(head -n1 $tmp/exec.err)" "awk: system is unsafe ... status.awk"
@@ -125,7 +118,7 @@ try "allow unsafe status script"
 	cat > $ENTR_STATUS_SCRIPT <<-EOF
 	{ system("date") }
 	EOF
-	ls $tmp/* | ./entr -zxx true >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zxx true >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	assert "$(head -n1 $tmp/exec.err)" ""
 
@@ -137,7 +130,7 @@ try "use custom status script"
 	  print "=", $1, $2, "="
 	}
 	EOF
-	ls $tmp/* | ./entr -zx false >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zx false >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	assert "$(cat $tmp/exec.err)" ""
 	assert "$(cat $tmp/exec.out)" "$(printf '= exit 1 =')"
@@ -150,7 +143,7 @@ try "use custom status script with shell option and kill"
 	  print "=", $1, $2, "="
 	}
 	EOF
-	ls $tmp/* | ./entr -zx -s 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -zx -s 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	assert "$(cat $tmp/exec.err)" ""
 	assert "$(cat $tmp/exec.out)" "$(printf '= signal 9 =')"
@@ -161,7 +154,7 @@ try "abort if status script terminates"
 	cat > $ENTR_STATUS_SCRIPT <<-'EOF'
 	{ exit; }
 	EOF
-	ls $tmp/* | ./entr -x true >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/* | entr -x true >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	assert "$(cat $tmp/exec.err)" "entr: status process terminated"
 	assert "$(cat $tmp/exec.out)" ""
@@ -172,7 +165,7 @@ unset TMUX
 
 try "spacebar triggers utility"
 	setup
-	tmux new-session -s $tsession -d
+	env SHELL=/bin/sh tmux new-session -s $tsession -d
 	echo "waiting" > $tmp/file1
 	echo "finished" > $tmp/file2
 	tmux send-keys -t $tsession:0 \
@@ -189,7 +182,7 @@ try "spacebar triggers utility"
 
 try "exec a command using one-shot option"
 	setup
-	ls $tmp/file2 | ./entr -zp cat $tmp/file2 >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/file2 | entr -zp cat $tmp/file2 >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	echo 456 >> $tmp/file2 ; zz
 	wait $bgpid; assert "$?" "0"
@@ -198,25 +191,25 @@ try "exec a command using one-shot option"
 
 try "exec a command using one-shot option and return signal number"
 	setup
-	ls $tmp/file2 | ./entr -z sh -c 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err
+	ls $tmp/file2 | entr -z sh -c 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err
 	assert "$?" "137"
 	assert "$(cat $tmp/exec.err)" ""
 	assert "$(cat $tmp/exec.out)" ""
 
 try "exec a command using one-shot and shell options and return signal"
 	setup
-	ls $tmp/file2 | ./entr -z -s 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err
+	ls $tmp/file2 | entr -z -s 'kill -9 $$' >$tmp/exec.out 2>$tmp/exec.err
 	assert "$?" "137"
 	assert "$(tail -c23  $tmp/exec.out)" ""
 
 try "fail to exec a command using one-shot option"
 	setup
-	ls $tmp/file* | ./entr -z /usr/bin/false_X 2>$tmp/exec.err
+	ls $tmp/file* | entr -z /usr/bin/false_X 2>$tmp/exec.err
 	assert "$?" "1"
 
 try "exec a command using one-shot option exit code from child"
 	setup
-	ls $tmp/file* | ./entr -z sh -c 'exit 4' &
+	ls $tmp/file* | entr -z sh -c 'exit 4' &
 	bgpid=$! ; zz
 	wait $bgpid; assert "$?" "4"
 
@@ -225,7 +218,7 @@ try "restart a server when a file is modified using one-shot option"
 	if [ $(uname) == 'Linux' ]; then
 		skip "GNU nc spins while retrying SELECT(2); busybox does not support domain sockets"
 	else
-		ls $tmp/file2 | ./entr -rz nc -l -U $tmp/nc.s >> $tmp/exec.out &
+		ls $tmp/file2 | entr -rz nc -l -U $tmp/nc.s >> $tmp/exec.out &
 		bgpid=$! ; zz
 		echo "123" | nc -NU $tmp/nc.s 2> /dev/null || {
 			echo "123" | nc -U $tmp/nc.s
@@ -237,7 +230,7 @@ try "restart a server when a file is modified using one-shot option"
 
 try "exec a command in non-intertive mode"
 	setup
-	ls $tmp/file* | ./entr -n tty >$tmp/exec.out &
+	ls $tmp/file* | entr tty >$tmp/exec.out &
 	bgpid=$! ; zz
 	kill -INT $bgpid
 	wait $bgpid; assert "$?" "0"
@@ -245,7 +238,7 @@ try "exec a command in non-intertive mode"
 
 try "exec a command as a background task and ensure stdin is closed"
 	setup
-	ls $tmp/file* | ./entr -r sh -c 'test -t 0; echo $?; kill $$' >$tmp/exec.out &
+	ls $tmp/file* | entr -r sh -c 'test -t 0; echo $?; kill $$' >$tmp/exec.out &
 	bgpid=$! ; zz
 	kill -INT $bgpid
 	wait $bgpid; assert "$?" "0"
@@ -253,7 +246,7 @@ try "exec a command as a background task and ensure stdin is closed"
 
 try "exec a command as a background task, and verify that read from stdin doesn't complain"
 	setup
-	ls $tmp/file* | ./entr -r sh -c 'read X' 2>$tmp/exec.err &
+	ls $tmp/file* | entr -r sh -c 'read X' 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	kill -INT $bgpid
 	wait $bgpid; assert "$?" "0"
@@ -261,7 +254,7 @@ try "exec a command as a background task, and verify that read from stdin doesn'
 
 try "exec single shell utility and exit when a file is added to an implicit watch path"
 	setup
-	ls $tmp/file* | ./entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
+	ls $tmp/file* | entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
 	    || true &
 	bgpid=$! ; zz
 	touch $tmp/newfile
@@ -271,7 +264,7 @@ try "exec single shell utility and exit when a file is added to an implicit watc
 
 try "exec single shell utility and exit when a subdirectory is added"
 	setup
-	ls -d $tmp | ./entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
+	ls -d $tmp | entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
 	    || true &
 	bgpid=$! ; zz
 	mkdir $tmp/newdir
@@ -282,7 +275,7 @@ try "exec single shell utility and exit when a subdirectory is added"
 
 try "exec single shell utility and exit when a hidden subdirectory is added"
 	setup
-	ls -d $tmp | ./entr -ddp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
+	ls -d $tmp | entr -ddp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
 	    || true &
 	bgpid=$! ; zz
 	mkdir $tmp/.newdir
@@ -293,7 +286,7 @@ try "exec single shell utility and exit when a hidden subdirectory is added"
 
 try "exec single shell utility and exit when a file is added to a specific path"
 	setup
-	ls -d $tmp | ./entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
+	ls -d $tmp | entr -dp sh -c 'echo ping' >$tmp/exec.out 2>$tmp/exec.err \
 	    || true &
 	bgpid=$! ; zz
 	touch $tmp/newfile
@@ -303,7 +296,7 @@ try "exec single shell utility and exit when a file is added to a specific path"
 
 try "do nothing when a file not monitored is changed in directory watch mode"
 	setup
-	ls $tmp/file2 | ./entr -dp echo "changed" >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/file2 | entr -dp echo "changed" >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	echo "123" > $tmp/file1
 	kill -INT $bgpid
@@ -313,7 +306,7 @@ try "do nothing when a file not monitored is changed in directory watch mode"
 
 try "exec utility when a file is written by Vim in directory watch mode"
 	setup
-	ls $tmp/file* | ./entr -dp echo "changed" >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/file* | entr -dp echo "changed" >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	vim -e -s -u NONE -N \
 	    -c ":r!date" \
@@ -326,7 +319,7 @@ try "exec utility when a file is written by Vim in directory watch mode"
 try "exec utility when a file is opened for write and then closed"
 	setup
 	echo "---" > $tmp/file1
-	ls $tmp/file* | ./entr -p echo "changed" > $tmp/exec.out &
+	ls $tmp/file* | entr -p echo "changed" > $tmp/exec.out &
 	bgpid=$! ; zz
 	: > $tmp/file1 ; zz
 	kill -INT $bgpid
@@ -353,19 +346,20 @@ try "exec single utility when an entire stash of files is reverted"
 			echo "" >> $f
 		done
 		cd - > /dev/null ; zz
-		ls $tmp/*.h | ./entr -p echo "changed" > $tmp/exec.out &
+		ls $tmp/*.h | entr -p echo "changed" > $tmp/exec.out &
 		bgpid=$! ; zz
 		cd $tmp
 		git checkout *.h -q
 		cd - > /dev/null ; zz
 		kill -INT $bgpid
 		wait $bgpid; assert "$?" "0"
+		rm -rf $tmp/.git
 		assert "$(cat $tmp/exec.out)" "changed"
 	fi
 
 try "exec utility when a file is written by Vim"
 	setup
-	ls $tmp/file* | ./entr -p echo "changed" > $tmp/exec.out &
+	ls $tmp/file* | entr -p echo "changed" > $tmp/exec.out &
 	bgpid=$! ; zz
 	vim -e -s -u NONE -N \
 	    -c ":r!date" \
@@ -376,7 +370,7 @@ try "exec utility when a file is written by Vim"
 
 try "exec shell utility when a file is written by Vim with 'backup'"
 	setup
-	ls $tmp/file* | ./entr -p echo "changed" > $tmp/exec.out &
+	ls $tmp/file* | entr -p echo "changed" > $tmp/exec.out &
 	bgpid=$! ; zz
 	vim -e -s -u NONE -N \
 	    -c ":set backup" \
@@ -388,7 +382,7 @@ try "exec shell utility when a file is written by Vim with 'backup'"
 
 try "exec shell utility when a file is written by Vim with 'nowritebackup'"
 	setup
-	ls $tmp/file* | ./entr -p echo "changed" > $tmp/exec.out &
+	ls $tmp/file* | entr -p echo "changed" > $tmp/exec.out &
 	bgpid=$! ; zz
 	vim -e -s -u NONE -N \
 	    -c ":set nowritebackup" \
@@ -401,7 +395,7 @@ try "exec shell utility when a file is written by Vim with 'nowritebackup'"
 try "restart a server when a file is modified"
 	setup
 	echo "started." > $tmp/file1
-	ls $tmp/file2 | ./entr -r tail -f $tmp/file1 2> /dev/null > $tmp/exec.out &
+	ls $tmp/file2 | entr -r tail -f $tmp/file1 2> /dev/null > $tmp/exec.out &
 	bgpid=$! ; zz
 	assert "$(cat $tmp/exec.out)" "started."
 	echo 456 >> $tmp/file2 ; zz
@@ -417,7 +411,7 @@ try "ensure that all shell subprocesses are terminated in restart mode"
 	echo "running"; sleep 10
 	SCRIPT
 	chmod +x $tmp/go.sh
-	ls $tmp/file2 | ./entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
+	ls $tmp/file2 | entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
 	bgpid=$! ; zz
 	kill -INT $bgpid ; zz
 	assert "$(cat $tmp/exec.out)" "$(printf 'running\ncaught signal')"
@@ -430,7 +424,7 @@ try "ensure that all shell subprocesses are terminated when terminal is closed"
 	echo "running"; sleep 10
 	SCRIPT
 	chmod +x $tmp/go.sh
-	ls $tmp/file2 | ./entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
+	ls $tmp/file2 | entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
 	bgpid=$! ; zz
 	kill -HUP $bgpid ; zz
 	assert "$(cat $tmp/exec.out)" "$(printf 'running\ncaught signal')"
@@ -438,7 +432,7 @@ try "ensure that all shell subprocesses are terminated when terminal is closed"
 try "exit with no action when restart and dirwatch flags are combined"
 	setup
 	echo "started." > $tmp/file1
-	ls $tmp/file* | ./entr -rd tail -f $tmp/file1 2> /dev/null > $tmp/exec.out &
+	ls $tmp/file* | entr -rd tail -f $tmp/file1 2> /dev/null > $tmp/exec.out &
 	bgpid=$! ; zz
 	assert "$(cat $tmp/exec.out)" "started."
 	touch $tmp/newfile
@@ -449,7 +443,7 @@ try "exit with no action when restart and dirwatch flags are combined"
 try "exec single shell utility when two files change simultaneously"
 	setup
 	ln $tmp/file1 $tmp/file3
-	ls $tmp/file* | ./entr -p sh -c 'echo ping' > $tmp/exec.out &
+	ls $tmp/file* | entr -p sh -c 'echo ping' > $tmp/exec.out &
 	bgpid=$! ; zz
 	echo 456 >> $tmp/file1 ; zz
 	kill -INT $bgpid
@@ -458,7 +452,7 @@ try "exec single shell utility when two files change simultaneously"
 
 try "exec single shell utility on startup and when a file is changed"
 	setup
-	ls $tmp/file* | ./entr sh -c 'printf ping' > $tmp/exec.out &
+	ls $tmp/file* | entr sh -c 'printf ping' > $tmp/exec.out &
 	bgpid=$! ; zz
 	echo 456 >> $tmp/file1 ; zz
 	kill -INT $bgpid
@@ -467,7 +461,7 @@ try "exec single shell utility on startup and when a file is changed"
 
 try "exec a command if a file is made executable"
 	setup
-	ls $tmp/file* | ./entr -p echo /_ > $tmp/exec.out &
+	ls $tmp/file* | entr -p echo /_ > $tmp/exec.out &
 	bgpid=$! ; zz
 	chmod +x $tmp/file2 ; zz
 	kill -INT $bgpid
@@ -477,7 +471,7 @@ try "exec a command if a file is made executable"
 try "ensure watches operate on a running executable"
 	setup
 	cp /bin/sleep $tmp/
-	ls $tmp/sleep | ./entr -rs "echo 'vroom'; $tmp/sleep 30" \
+	ls $tmp/sleep | entr -rs "echo 'vroom'; $tmp/sleep 30" \
 	    > $tmp/exec.out 2> /dev/null &
 	bgpid=$! ; zz
 	cp -f /bin/sleep $tmp/ ; zz
@@ -488,7 +482,7 @@ try "ensure watches operate on a running executable"
 
 try "exec a command using the first file to change"
 	setup
-	ls $tmp/file* | ./entr -p cat /_ > $tmp/exec.out &
+	ls $tmp/file* | entr -p cat /_ > $tmp/exec.out &
 	bgpid=$! ; zz
 	echo 456 > $tmp/file1 ; zz
 	kill -INT $bgpid
@@ -497,7 +491,7 @@ try "exec a command using the first file to change"
 
 try "exec single shell utility using utility substitution"
 	setup
-	ls $tmp/file1 $tmp/file2 | ./entr -p file /_ > $tmp/exec.out &
+	ls $tmp/file1 $tmp/file2 | entr -p file /_ > $tmp/exec.out &
 	bgpid=$! ; zz
 	echo 456 >> $tmp/file2; zz
 	kill -INT $bgpid
@@ -507,7 +501,7 @@ try "exec single shell utility using utility substitution"
 try "watch and exec a program that is overwritten"
 	setup
 	touch $tmp/script; chmod 755 $tmp/script
-	echo $tmp/script | ./entr -p $tmp/script $tmp/file1 > $tmp/exec.out &
+	echo $tmp/script | entr -p $tmp/script $tmp/file1 > $tmp/exec.out &
 	bgpid=$! ; zz
 	cat > $tmp/script <<-EOF
 	#!/bin/sh
@@ -519,20 +513,20 @@ try "watch and exec a program that is overwritten"
 
 try "exec an interactive utility when a file changes"
 	setup
-	ls $tmp/file* | ./entr -p sh -c 'tty | cut -c1-8' 2> /dev/null > $tmp/exec.out &
-	bgpid=$! ; zz
-	echo 456 >> $tmp/file2 ; zz
-	kill -INT $bgpid
-	wait $bgpid; assert "$?" "0"
 	if ! test -t 0 ; then
 		skip "A TTY is not available"
 	else
+		ls $tmp/file* | entr_tty -p sh -c 'tty | cut -c1-9' 2> /dev/null > $tmp/exec.out &
+		bgpid=$! ; zz
+		echo 456 >> $tmp/file2 ; zz
+		kill -INT $bgpid
+		wait $bgpid; assert "$?" "0"
 		assert "$(cat $tmp/exec.out | tr '/pts' '/tty')" "/dev/tty"
 	fi
 
 try "exec a command using shell option"
 	setup
-	ls $tmp/file* | ./entr -ps 'file $0; exit 2' >$tmp/exec.out 2>$tmp/exec.err &
+	ls $tmp/file* | entr -ps 'file $0; exit 2' >$tmp/exec.out 2>$tmp/exec.err &
 	bgpid=$! ; zz
 	echo 456 >> $tmp/file2 ; zz
 	kill -INT $bgpid
@@ -542,7 +536,7 @@ try "exec a command using shell option"
 
 try "exec a command as a background task"
 	setup
-	(ls $tmp/file* | ./entr -ps 'echo terminating; kill $$' >$tmp/exec.out 2>$tmp/exec.err &)
+	(ls $tmp/file* | entr -ps 'echo terminating; kill $$' >$tmp/exec.out 2>$tmp/exec.err &)
 	zz
 	echo 456 >> $tmp/file2 ; zz
 	assert "$(cat $tmp/exec.err)" ""
@@ -552,7 +546,7 @@ try "exec a command as a background task"
 
 try "respond to events that occur while the utility is running"
 	setup
-	ls $tmp/file* | ./entr -a sh -c 'echo "vroom"; sleep 0.5' > $tmp/exec.out &
+	ls $tmp/file* | entr -a sh -c 'echo "vroom"; sleep 0.5' > $tmp/exec.out &
 	bgpid=$! ; zz
 	echo "123" > $tmp/file1
 	sleep 1
@@ -568,11 +562,12 @@ try "ensure that all subprocesses are terminated in restart mode when a file is
 	echo "running"; sleep 10
 	SCRIPT
 	chmod +x $tmp/go.sh
-	ls $tmp/file2 | ./entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
+	ls $tmp/file2 | entr -r sh -c "$tmp/go.sh" 2> /dev/null > $tmp/exec.out &
 	bgpid=$! ; zz
 	rm $tmp/file2; sleep 2
 	pgrep -P $bgpid > /dev/null || assert "$?" "1"
 	assert "$(cat $tmp/exec.out)" "$(printf 'running\ncaught signal')"
 
 this="exit 0"
-echo; echo "$tests tests PASSED"
+echo
+echo "$tests tests PASSED"
